@@ -15,7 +15,7 @@ use crossterm::terminal as term;
 use mlua::LuaSerdeExt;
 use std::fs;
 use std::io;
-use std::io::prelude::*;
+use std::path::PathBuf;
 use std::process::{Command, ExitStatus, Stdio};
 use std::sync::mpsc;
 use termion::get_tty;
@@ -86,10 +86,10 @@ fn call(app: &app::App, cmd: app::Command, silent: bool) -> io::Result<ExitStatu
         .status()
 }
 
-pub fn run(
+pub(crate) fn run(
     mut app: app::App,
-    focused_path: Option<String>,
-    lua: mlua::Lua,
+    focused_path: Option<PathBuf>,
+    lua: &mlua::Lua,
 ) -> Result<Option<String>> {
     fs::create_dir_all(app.session_path())?;
 
@@ -99,7 +99,10 @@ pub fn run(
 
     app = app.explore_pwd()?;
 
-    app = if let Some(f) = focused_path.clone() {
+    app = if let Some(f) = focused_path
+        .clone()
+        .map(|f| f.to_string_lossy().to_string())
+    {
         app.focus_by_file_name(&f, true)?
     } else {
         app.focus_first(true)?
@@ -107,8 +110,9 @@ pub fn run(
 
     explorer::explore_recursive_async(
         app.explorer_config().clone(),
-        app.pwd().clone(),
+        app.pwd().into(),
         focused_path,
+        app.directory_buffer().map(|d| d.focus()).unwrap_or(0),
         tx_msg_in.clone(),
     );
     tx_pwd_watcher.send(app.pwd().clone())?;
@@ -120,7 +124,14 @@ pub fn run(
     let mut stdout = get_tty()?;
     // let mut stdout = stdout.lock();
     execute!(stdout, term::EnterAlternateScreen)?;
-    execute!(stdout, event::EnableMouseCapture).unwrap_or_default(); // Optional
+
+    let mut mouse_enabled = app.config().general().enable_mouse();
+    if mouse_enabled {
+        if let Err(e) = execute!(stdout, event::EnableMouseCapture) {
+            app = app.log_error(e.to_string())?;
+        }
+    }
+
     let backend = CrosstermBackend::new(stdout);
     let mut terminal = Terminal::new(backend)?;
     terminal.hide_cursor()?;
@@ -170,8 +181,9 @@ pub fn run(
                         app::MsgOut::ExplorePwdAsync => {
                             explorer::explore_async(
                                 app.explorer_config().clone(),
-                                app.pwd().clone(),
-                                app.focused_node().map(|n| n.relative_path().clone()),
+                                app.pwd().into(),
+                                app.focused_node().map(|n| n.relative_path().into()),
+                                app.directory_buffer().map(|d| d.focus()).unwrap_or(0),
                                 tx_msg_in.clone(),
                             );
                             tx_pwd_watcher.send(app.pwd().clone())?;
@@ -180,8 +192,9 @@ pub fn run(
                         app::MsgOut::ExploreParentsAsync => {
                             explorer::explore_recursive_async(
                                 app.explorer_config().clone(),
-                                app.pwd().clone(),
-                                app.focused_node().map(|n| n.relative_path().clone()),
+                                app.pwd().into(),
+                                app.focused_node().map(|n| n.relative_path().into()),
+                                app.directory_buffer().map(|d| d.focus()).unwrap_or(0),
                                 tx_msg_in.clone(),
                             );
                             tx_pwd_watcher.send(app.pwd().clone())?;
@@ -194,6 +207,42 @@ pub fn run(
                             terminal.draw(|f| ui::draw(f, &app, &lua))?;
                         }
 
+                        app::MsgOut::EnableMouse => {
+                            if !mouse_enabled {
+                                match execute!(terminal.backend_mut(), event::EnableMouseCapture) {
+                                    Ok(_) => {
+                                        mouse_enabled = true;
+                                    }
+                                    Err(e) => {
+                                        app = app.log_error(e.to_string())?;
+                                    }
+                                }
+                            }
+                        }
+
+                        app::MsgOut::ToggleMouse => {
+                            let msg = if mouse_enabled {
+                                app::ExternalMsg::DisableMouse
+                            } else {
+                                app::ExternalMsg::EnableMouse
+                            };
+                            app =
+                                app.handle_task(app::Task::new(app::MsgIn::External(msg), None))?;
+                        }
+
+                        app::MsgOut::DisableMouse => {
+                            if mouse_enabled {
+                                match execute!(terminal.backend_mut(), event::DisableMouseCapture) {
+                                    Ok(_) => {
+                                        mouse_enabled = false;
+                                    }
+                                    Err(e) => {
+                                        app = app.log_error(e.to_string())?;
+                                    }
+                                }
+                            }
+                        }
+
                         app::MsgOut::CallLuaSilently(func) => {
                             tx_event_reader.send(true)?;
 
@@ -254,7 +303,7 @@ pub fn run(
 
                         app::MsgOut::CallLua(func) => {
                             execute!(terminal.backend_mut(), event::DisableMouseCapture)
-                                .unwrap_or_default(); // Optional
+                                .unwrap_or_default();
 
                             tx_event_reader.send(true)?;
 
@@ -283,13 +332,21 @@ pub fn run(
                             terminal.hide_cursor()?;
                             tx_event_reader.send(false)?;
 
-                            execute!(terminal.backend_mut(), event::EnableMouseCapture)
-                                .unwrap_or_default(); // Optional
+                            if mouse_enabled {
+                                match execute!(terminal.backend_mut(), event::EnableMouseCapture) {
+                                    Ok(_) => {
+                                        mouse_enabled = true;
+                                    }
+                                    Err(e) => {
+                                        app = app.log_error(e.to_string())?;
+                                    }
+                                }
+                            }
                         }
 
                         app::MsgOut::Call(cmd) => {
                             execute!(terminal.backend_mut(), event::DisableMouseCapture)
-                                .unwrap_or_default(); // Optional
+                                .unwrap_or_default();
 
                             tx_event_reader.send(true)?;
 
@@ -334,8 +391,16 @@ pub fn run(
                             terminal.hide_cursor()?;
                             tx_event_reader.send(false)?;
 
-                            execute!(terminal.backend_mut(), event::EnableMouseCapture)
-                                .unwrap_or_default(); // Optional
+                            if mouse_enabled {
+                                match execute!(terminal.backend_mut(), event::EnableMouseCapture) {
+                                    Ok(_) => {
+                                        mouse_enabled = true;
+                                    }
+                                    Err(e) => {
+                                        app = app.log_error(e.to_string())?;
+                                    }
+                                }
+                            }
                         }
                     };
                 }
@@ -351,7 +416,7 @@ pub fn run(
     terminal.clear()?;
     terminal.set_cursor(0, 0)?;
     execute!(terminal.backend_mut(), term::LeaveAlternateScreen)?;
-    execute!(terminal.backend_mut(), event::DisableMouseCapture).unwrap_or_default(); // Optional
+    execute!(terminal.backend_mut(), event::DisableMouseCapture).unwrap_or_default();
     term::disable_raw_mode()?;
     terminal.show_cursor()?;
 
